#!/usr/bin/env python<PYVERSION>
# -*- coding: utf-8; mode: python; -*-
<LICENSE_HEADER>
"""<PROJECT>'s defined errors"""


class <PROJECT>Error(Exception):
    """Base error for <PROJECT>(Exception)"""
    def __init__(self, *args):
        super().__init__(*args)
